# microprediction

Collective microprediction client leveraging www.microprediction.com 

    pip install microprediction 
    
This library is still under construction. There is a teaser at https://vimeo.com/397352413

## Most up to date usage instructions:

https://github.com/microprediction/microprediction/blob/master/README_MICROPREDICTION.md